@@ -15,8 +15,6 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjviewprefs.cpp,v 1.53 2010/01/28 17:11:24 leonb Exp $
-
 #if AUTOCONF
 # include "config.h"
 #endif
@@ -26,6 +24,7 @@
 #include <libdjvu/miniexp.h>
 #include <libdjvu/ddjvuapi.h>
 
+#include <QColor>
 #include <QComboBox>
 #include <QCoreApplication>
 #include <QDebug>
@@ -134,6 +133,7 @@ QDjViewPrefs::QDjViewPrefs(void)
     windowSize(640,400),
     tools(defaultTools),
     gamma(2.2),
+    white(QColor(Qt::white)),
     resolution(100),
     cacheSize(10*1024*1024),
     pixelCacheSize(256*1024),
@@ -323,6 +323,8 @@ QDjViewPrefs::load()
     tools |= TOOL_BACKFORW;
   if (s.contains("gamma"))
     gamma = s.value("gamma").toDouble();
+  if (s.contains("white"))
+    white = QColor(s.value("white").toString());
   if (s.contains("resolution"))
     resolution = s.value("resolution").toInt();
   if (s.contains("cacheSize"))
@@ -418,6 +420,7 @@ QDjViewPrefs::save(void)
   s.setValue("windowSize", windowSize);
   s.setValue("tools", toolsToString(tools));
   s.setValue("gamma", gamma);
+  s.setValue("white", white.name());
   s.setValue("resolution", resolution);
   s.setValue("cacheSize", cacheSize);
   s.setValue("pixelCacheSize", pixelCacheSize);
