@@ -15,8 +15,6 @@
 //C- GNU General Public License for more details.
 //C-  ------------------------------------------------------------------
 
-// $Id: qdjvuwidget.h,v 1.40 2009/02/22 16:50:54 leonb Exp $
-
 #ifndef QDJVUWIDGET_H
 #define QDJVUWIDGET_H
 
@@ -47,6 +45,8 @@ class QDjVuWidget : public QAbstractScrollArea
              READ zoom WRITE setZoom)
   Q_PROPERTY(double gamma 
              READ gamma WRITE setGamma)
+  Q_PROPERTY(QColor white
+             READ white WRITE setWhite)
   Q_PROPERTY(int screenDpi 
              READ screenDpi WRITE setScreenDpi)
   Q_PROPERTY(DisplayMode displayMode 
@@ -138,7 +138,7 @@ public:
     QPoint posPage;
     QPoint posView;
     bool   inPage;
-    bool   valid;
+    bool   doPage;
     char   hAnchor;
     char   vAnchor;
     Position();
@@ -168,6 +168,7 @@ public:
   int zoom(void) const;
   int zoomFactor(void) const;
   double gamma(void) const;
+  QColor white(void) const;
   int screenDpi(void) const;
   DisplayMode displayMode(void) const;
   bool displayFrame(void) const;
@@ -200,6 +201,7 @@ public slots:
   void setRotation(int);
   void setZoom(int);
   void setGamma(double);
+  void setWhite(QColor);
   void setScreenDpi(int);
   void setDisplayMode(DisplayMode m);
   void setDisplayFrame(bool);
